@@ -853,9 +853,9 @@ def check_conflicting_branch_and_hash(context: CertoraContext) -> None:
         if context.local:
             raise Util.CertoraUserInputError("Cannot run on a specific commit in local runs. "
                                              "Did you mean to use --staging?")
-        elif context.domain == Util.PRODUCTION_DOMAIN:
-            raise Util.CertoraUserInputError("Cannot run on a specific commit in production. "
-                                             "Did you mean to use --staging?")
+        # elif context.domain == Util.PRODUCTION_DOMAIN:
+            # raise Util.CertoraUserInputError("Cannot run on a specific commit in production. "
+                                            #  "Did you mean to use --staging?")
         elif context.staging:  # A non-empty string
             raise Util.CertoraUserInputError(f"Cannot run on both a specific branch {context.staging} "
                                              f"and a specific commit {commit_hash}")
